@@ -167,7 +167,7 @@
          else TableKind
       end as table_type
     from DBC.TablesV
-    where DatabaseName = '{{ schema_relation.schema }}'
+    where DatabaseName = '{{ schema_relation.schema }}' (NOT CASESPECIFIC)
       and TableKind in ('T', 'V')
 
   {% endcall %}
@@ -202,3 +202,14 @@
   {%- endif -%}
 
 {% endmacro %}
+
+{% macro teradata__get_columns_in_query(select_sql) %}
+    {% call statement('get_columns_in_query', fetch_result=True, auto_begin=False) -%}
+        select * from (
+            {{ select_sql }}
+        ) as __dbt_sbq
+        where 0=1
+    {% endcall %}
+
+    {{ return(load_result('get_columns_in_query').table.columns | map(attribute='name') | list) }}
+{% endmacro %}
